==> v5.0.1.tar.gz: 2fauth/resources/lang/ru/titles.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Titles Language Lines
    |--------------------------------------------------------------------------
    |
    */

    'start' => 'Новая учетная запись',
    'capture' => 'Отсканируйте QR',
    'accounts' => 'Учётные записи',
    'createAccount' => 'Создать учётную запись',
    'importAccounts' => 'Импорт учётных записей',
    'editAccount' => 'Редактирование учетной записи',
    'showQRcode' => 'Учетная запись как QR-код',
    'groups' => 'Группы',
    'createGroup' => 'Создать группу',
    'editGroup' => 'Изменение группы',
    'settings' => [
        'options' => 'Настройки',
        'account' => 'Учетные записи пользователя',
        'oauth' => [
            'tokens' => 'OAuth Токены',
            'generatePAT' => 'Новый персональный токен',
        ],
        'webauthn' => [
            'editCredential' => 'Редактирование устройства',
            'devices' => 'Устройства WebAuthn',
        ],
    ],
    'login' => 'Вход',
    'register' => 'Регистрация',
    'autolock' => 'Автоблокировка',
    'password' => [
        'request' => 'Восстановить пароль',
        'reset' => 'Новый пароль',
    ],
    'webauthn' => [
        'lost' => 'Восстановление доступа к аккаунту',
        'recover' => 'Зарегистрировать новое устройство',
    ],
    'flooded' => 'Слишком много запросов',
    'genericError' => 'Ошибка',
    '404' => 'Элемент не найден',
    'about' => 'О программе',
];

==> v5.0.3.tar.gz: 2fauth/resources/lang/ru/titles.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Titles Language Lines
    |--------------------------------------------------------------------------
    |
    */

    'start' => 'Новая учетная запись',
    'capture' => 'Отсканируйте QR',
    'accounts' => 'Учётные записи',
    'createAccount' => 'Создать учётную запись',
    'importAccounts' => 'Импорт учётных записей',
    'editAccount' => 'Редактирование учетной записи',
    'showQRcode' => 'Учетная запись как QR-код',
    'groups' => 'Группы',
    'createGroup' => 'Создать группу',
    'editGroup' => 'Изменение группы',
    'settings' => [
        'options' => 'Настройки',
        'account' => 'Учетные записи пользователя',
        'oauth' => [
            'tokens' => 'OAuth Токены',
            'generatePAT' => 'Новый персональный токен',
        ],
        'webauthn' => [
            'editCredential' => 'Редактирование устройства',
            'devices' => 'Устройства WebAuthn',
        ],
    ],
    'login' => 'Вход',
    'register' => 'Регистрация',
    'autolock' => 'Автоблокировка',
    'password' => [
        'request' => 'Восстановить пароль',
        'reset' => 'Новый пароль',
    ],
    'webauthn' => [
        'lost' => 'Восстановление доступа к учётной записи',
        'recover' => 'Зарегистрировать новое устройство',
    ],
    'flooded' => 'Слишком много запросов',
    'genericError' => 'Ошибка',
    '404' => 'Элемент не найден',
    'about' => 'О программе',
];
